@@ -40,13 +40,12 @@ from ...utils import (
 
 
 class NetworkAccessNetworkConditions(object):
-    """Identity Services Engine Network Access - Network Conditions API (version: 3.1.1).
+    """Identity Services Engine Network Access - Network Conditions API (version: 3.1.0).
 
     Wraps the Identity Services Engine Network Access - Network Conditions
     API and exposes the API as native Python
     methods that return native Python objects.
 
-    Policy APIs for manage Policy Sets, authorization policies, authentication policies, and policy elements.
 
     """
 
@@ -125,13 +124,13 @@ class NetworkAccessNetworkConditions(object):
         else:
             _api_response = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_d43fec9e7dc556cbb9bf0ebd1dcd6aad_v3_1_1', _api_response)
+        return self._object_factory('bpm_d43fec9e7dc556cbb9bf0ebd1dcd6aad_v3_1_0', _api_response)
 
     def get_all(self,
                 headers=None,
                 **query_parameters):
         """Alias for `get_network_access_network_conditions <#ciscoisesdk.
-        api.v3_1_1.network_access_network_conditions.
+        api.v3_1_0.network_access_network_conditions.
         NetworkAccessNetworkConditions.get_network_access_network_conditions>`_
         """
         return self.get_network_access_network_conditions(
@@ -140,15 +139,11 @@ class NetworkAccessNetworkConditions(object):
         )
 
     def create_network_access_network_condition(self,
-                                                cli_dnis_list=None,
                                                 condition_type=None,
+                                                conditions=None,
                                                 description=None,
-                                                device_group_list=None,
-                                                device_list=None,
                                                 id=None,
-                                                ip_addr_list=None,
                                                 link=None,
-                                                mac_addr_list=None,
                                                 name=None,
                                                 headers=None,
                                                 payload=None,
@@ -157,49 +152,18 @@ class NetworkAccessNetworkConditions(object):
         """Network Access Creates network condition.
 
         Args:
-            cli_dnis_list(list): This field should contain a Caller
-                ID (CLI), comma, and Called ID (DNIS).
-                Line format  Caller ID (CLI), Called ID
-                (DNIS), property of the request body
-                (list of strings).
             condition_type(string): This field determines the
                 content of the conditions field,
                 property of the request body. Available
                 values are 'DeviceCondition',
                 'DevicePortCondition' and
                 'EndstationCondition'.
+            conditions(list): conditions, property of the request
+                body (list of objects).
             description(string): description, property of the
                 request body.
-            device_group_list(list): This field should contain a
-                tuple with NDG Root, comma, and an NDG
-                (that it under the root).  Line format
-                NDG Root Name, NDG, Port, property of
-                the request body (list of strings).
-            device_list(list): This field should contain Device
-                Name. The device name must be the same
-                as the name field in a Network Device
-                object. Line format Device Name,
-                property of the request body (list of
-                strings).
             id(string): id, property of the request body.
-            ip_addr_list(list): This field should contain IP address
-                or subnet.  IP address can be IPV4
-                format (n.n.n.n) or IPV6 format
-                (n:n:n:n:n:n:n:n).  IP subnet can be
-                IPV4 format (n.n.n.n/m) or IPV6 format
-                (n:n:n:n:n:n:n:n/m).  Line format IP
-                Address or subnet, property of the
-                request body (list of strings).
             link(object): link, property of the request body.
-            mac_addr_list(list): This field should contain
-                Endstation MAC address, comma, and
-                Destination MAC addresses.  Each Max
-                address must include twelve hexadecimal
-                digits using formats nn:nn:nn:nn:nn:nn
-                or nn-nn-nn-nn-nn-nn or nnnn.nnnn.nnnn
-                or nnnnnnnnnnnn.  Line format Endstation
-                MAC,Destination MAC , property of the
-                request body (list of strings).
             name(string): Network Condition name, property of the
                 request body.
             headers(dict): Dictionary of HTTP Headers to send with the Request
@@ -265,21 +229,13 @@ class NetworkAccessNetworkConditions(object):
                     link,
                 'name':
                     name,
-                'deviceList':
-                    device_list,
-                'cliDnisList':
-                    cli_dnis_list,
-                'ipAddrList':
-                    ip_addr_list,
-                'macAddrList':
-                    mac_addr_list,
-                'deviceGroupList':
-                    device_group_list,
+                'conditions':
+                    conditions,
             }
             _payload.update(payload or {})
             _payload = dict_from_items_with_values(_payload)
         if active_validation and not is_xml_payload:
-            self._request_validator('jsd_f4dbfb874b3b56d7a651d6732f1bd55e_v3_1_1')\
+            self._request_validator('jsd_f4dbfb874b3b56d7a651d6732f1bd55e_v3_1_0')\
                 .validate(_payload)
 
         e_url = ('/api/v1/policy/network-access/network-condition')
@@ -294,37 +250,29 @@ class NetworkAccessNetworkConditions(object):
             _api_response = self._session.post(endpoint_full_url, params=_params,
                                                **request_params)
 
-        return self._object_factory('bpm_f4dbfb874b3b56d7a651d6732f1bd55e_v3_1_1', _api_response)
+        return self._object_factory('bpm_f4dbfb874b3b56d7a651d6732f1bd55e_v3_1_0', _api_response)
 
     def create(self,
-               cli_dnis_list=None,
                condition_type=None,
+               conditions=None,
                description=None,
-               device_group_list=None,
-               device_list=None,
                id=None,
-               ip_addr_list=None,
                link=None,
-               mac_addr_list=None,
                name=None,
                headers=None,
                payload=None,
                active_validation=True,
                **query_parameters):
         """Alias for `create_network_access_network_condition <#ciscoisesdk.
-        api.v3_1_1.network_access_network_conditions.
+        api.v3_1_0.network_access_network_conditions.
         NetworkAccessNetworkConditions.create_network_access_network_condition>`_
         """
         return self.create_network_access_network_condition(
-            cli_dnis_list=cli_dnis_list,
             condition_type=condition_type,
+            conditions=conditions,
             description=description,
-            device_group_list=device_group_list,
-            device_list=device_list,
             id=id,
-            ip_addr_list=ip_addr_list,
             link=link,
-            mac_addr_list=mac_addr_list,
             name=name,
             payload=payload,
             active_validation=active_validation,
@@ -392,14 +340,14 @@ class NetworkAccessNetworkConditions(object):
         else:
             _api_response = self._session.get(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_ab015a9eb6d5f2b91002af068cb4ce2_v3_1_1', _api_response)
+        return self._object_factory('bpm_ab015a9eb6d5f2b91002af068cb4ce2_v3_1_0', _api_response)
 
     def get_by_id(self,
                   id,
                   headers=None,
                   **query_parameters):
         """Alias for `get_network_access_network_condition_by_id <#ciscoisesdk.
-        api.v3_1_1.network_access_network_conditions.
+        api.v3_1_0.network_access_network_conditions.
         NetworkAccessNetworkConditions.get_network_access_network_condition_by_id>`_
         """
         return self.get_network_access_network_condition_by_id(
@@ -410,14 +358,10 @@ class NetworkAccessNetworkConditions(object):
 
     def update_network_access_network_condition_by_id(self,
                                                       id,
-                                                      cli_dnis_list=None,
                                                       condition_type=None,
+                                                      conditions=None,
                                                       description=None,
-                                                      device_group_list=None,
-                                                      device_list=None,
-                                                      ip_addr_list=None,
                                                       link=None,
-                                                      mac_addr_list=None,
                                                       name=None,
                                                       headers=None,
                                                       payload=None,
@@ -426,49 +370,18 @@ class NetworkAccessNetworkConditions(object):
         """Network Access Update network condition.
 
         Args:
-            cli_dnis_list(list): This field should contain a Caller
-                ID (CLI), comma, and Called ID (DNIS).
-                Line format  Caller ID (CLI), Called ID
-                (DNIS), property of the request body
-                (list of strings).
             condition_type(string): This field determines the
                 content of the conditions field,
                 property of the request body. Available
                 values are 'DeviceCondition',
                 'DevicePortCondition' and
                 'EndstationCondition'.
+            conditions(list): conditions, property of the request
+                body (list of objects).
             description(string): description, property of the
                 request body.
-            device_group_list(list): This field should contain a
-                tuple with NDG Root, comma, and an NDG
-                (that it under the root).  Line format
-                NDG Root Name, NDG, Port, property of
-                the request body (list of strings).
-            device_list(list): This field should contain Device
-                Name. The device name must be the same
-                as the name field in a Network Device
-                object. Line format Device Name,
-                property of the request body (list of
-                strings).
             id(string): id, property of the request body.
-            ip_addr_list(list): This field should contain IP address
-                or subnet.  IP address can be IPV4
-                format (n.n.n.n) or IPV6 format
-                (n:n:n:n:n:n:n:n).  IP subnet can be
-                IPV4 format (n.n.n.n/m) or IPV6 format
-                (n:n:n:n:n:n:n:n/m).  Line format IP
-                Address or subnet, property of the
-                request body (list of strings).
             link(object): link, property of the request body.
-            mac_addr_list(list): This field should contain
-                Endstation MAC address, comma, and
-                Destination MAC addresses.  Each Max
-                address must include twelve hexadecimal
-                digits using formats nn:nn:nn:nn:nn:nn
-                or nn-nn-nn-nn-nn-nn or nnnn.nnnn.nnnn
-                or nnnnnnnnnnnn.  Line format Endstation
-                MAC,Destination MAC , property of the
-                request body (list of strings).
             name(string): Network Condition name, property of the
                 request body.
             id(basestring): id path parameter. Condition id.
@@ -538,21 +451,13 @@ class NetworkAccessNetworkConditions(object):
                     link,
                 'name':
                     name,
-                'deviceList':
-                    device_list,
-                'cliDnisList':
-                    cli_dnis_list,
-                'ipAddrList':
-                    ip_addr_list,
-                'macAddrList':
-                    mac_addr_list,
-                'deviceGroupList':
-                    device_group_list,
+                'conditions':
+                    conditions,
             }
             _payload.update(payload or {})
             _payload = dict_from_items_with_values(_payload)
         if active_validation and not is_xml_payload:
-            self._request_validator('jsd_cf65cd559628b26f6eb5ea20f14_v3_1_1')\
+            self._request_validator('jsd_cf65cd559628b26f6eb5ea20f14_v3_1_0')\
                 .validate(_payload)
 
         e_url = ('/api/v1/policy/network-access/network-condition/{id}')
@@ -568,37 +473,29 @@ class NetworkAccessNetworkConditions(object):
             _api_response = self._session.put(endpoint_full_url, params=_params,
                                               **request_params)
 
-        return self._object_factory('bpm_cf65cd559628b26f6eb5ea20f14_v3_1_1', _api_response)
+        return self._object_factory('bpm_cf65cd559628b26f6eb5ea20f14_v3_1_0', _api_response)
 
     def update_by_id(self,
                      id,
-                     cli_dnis_list=None,
                      condition_type=None,
+                     conditions=None,
                      description=None,
-                     device_group_list=None,
-                     device_list=None,
-                     ip_addr_list=None,
                      link=None,
-                     mac_addr_list=None,
                      name=None,
                      headers=None,
                      payload=None,
                      active_validation=True,
                      **query_parameters):
         """Alias for `update_network_access_network_condition_by_id <#ciscoisesdk.
-        api.v3_1_1.network_access_network_conditions.
+        api.v3_1_0.network_access_network_conditions.
         NetworkAccessNetworkConditions.update_network_access_network_condition_by_id>`_
         """
         return self.update_network_access_network_condition_by_id(
             id=id,
-            cli_dnis_list=cli_dnis_list,
             condition_type=condition_type,
+            conditions=conditions,
             description=description,
-            device_group_list=device_group_list,
-            device_list=device_list,
-            ip_addr_list=ip_addr_list,
             link=link,
-            mac_addr_list=mac_addr_list,
             name=name,
             payload=payload,
             active_validation=active_validation,
@@ -666,14 +563,14 @@ class NetworkAccessNetworkConditions(object):
         else:
             _api_response = self._session.delete(endpoint_full_url, params=_params)
 
-        return self._object_factory('bpm_e92c6e47625711b9ce06f92bd4d219_v3_1_1', _api_response)
+        return self._object_factory('bpm_e92c6e47625711b9ce06f92bd4d219_v3_1_0', _api_response)
 
     def delete_by_id(self,
                      id,
                      headers=None,
                      **query_parameters):
         """Alias for `delete_network_access_network_condition_by_id <#ciscoisesdk.
-        api.v3_1_1.network_access_network_conditions.
+        api.v3_1_0.network_access_network_conditions.
         NetworkAccessNetworkConditions.delete_network_access_network_condition_by_id>`_
         """
         return self.delete_network_access_network_condition_by_id(
